@@ -9,11 +9,7 @@ from datetime import datetime
 from datetime import timedelta
 import pandas as pd
 #need this to use it in crontab
-import matplotlib
-matplotlib.use('Agg')
-import matplotlib.pyplot as plt
 import os
-import matplotlib.dates as md
 import sys
 import re
 import time
